==> kubernetes-model-storageclass-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/storage/CSIStorageCapacityListFluent.java <==
package io.fabric8.kubernetes.api.model.storage;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CSIStorageCapacityListFluent<A extends CSIStorageCapacityListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,CSIStorageCapacity item);
  public A setToItems(Integer index,CSIStorageCapacity item);
  public A addToItems(io.fabric8.kubernetes.api.model.storage.CSIStorageCapacity... items);
  public A addAllToItems(Collection<CSIStorageCapacity> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.storage.CSIStorageCapacity... items);
  public A removeAllFromItems(Collection<CSIStorageCapacity> items);
  public A removeMatchingFromItems(Predicate<CSIStorageCapacityBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CSIStorageCapacity> getItems();
  public List<CSIStorageCapacity> buildItems();
  public CSIStorageCapacity buildItem(Integer index);
  public CSIStorageCapacity buildFirstItem();
  public CSIStorageCapacity buildLastItem();
  public CSIStorageCapacity buildMatchingItem(Predicate<CSIStorageCapacityBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<CSIStorageCapacityBuilder> predicate);
  public A withItems(List<CSIStorageCapacity> items);
  public A withItems(io.fabric8.kubernetes.api.model.storage.CSIStorageCapacity... items);
  public Boolean hasItems();
  public CSIStorageCapacityListFluent.ItemsNested<A> addNewItem();
  public CSIStorageCapacityListFluent.ItemsNested<A> addNewItemLike(CSIStorageCapacity item);
  public CSIStorageCapacityListFluent.ItemsNested<A> setNewItemLike(Integer index,CSIStorageCapacity item);
  public CSIStorageCapacityListFluent.ItemsNested<A> editItem(Integer index);
  public CSIStorageCapacityListFluent.ItemsNested<A> editFirstItem();
  public CSIStorageCapacityListFluent.ItemsNested<A> editLastItem();
  public CSIStorageCapacityListFluent.ItemsNested<A> editMatchingItem(Predicate<CSIStorageCapacityBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,CSIStorageCapacityFluent<CSIStorageCapacityListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-storageclass-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/storage/CSIStorageCapacityListFluent.java <==
package io.fabric8.kubernetes.api.model.storage;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CSIStorageCapacityListFluent<A extends CSIStorageCapacityListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,CSIStorageCapacity item);
  public A setToItems(int index,CSIStorageCapacity item);
  public A addToItems(io.fabric8.kubernetes.api.model.storage.CSIStorageCapacity... items);
  public A addAllToItems(Collection<CSIStorageCapacity> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.storage.CSIStorageCapacity... items);
  public A removeAllFromItems(Collection<CSIStorageCapacity> items);
  public A removeMatchingFromItems(Predicate<CSIStorageCapacityBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CSIStorageCapacity> getItems();
  public List<CSIStorageCapacity> buildItems();
  public CSIStorageCapacity buildItem(int index);
  public CSIStorageCapacity buildFirstItem();
  public CSIStorageCapacity buildLastItem();
  public CSIStorageCapacity buildMatchingItem(Predicate<CSIStorageCapacityBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<CSIStorageCapacityBuilder> predicate);
  public A withItems(List<CSIStorageCapacity> items);
  public A withItems(io.fabric8.kubernetes.api.model.storage.CSIStorageCapacity... items);
  public Boolean hasItems();
  public CSIStorageCapacityListFluent.ItemsNested<A> addNewItem();
  public CSIStorageCapacityListFluent.ItemsNested<A> addNewItemLike(CSIStorageCapacity item);
  public CSIStorageCapacityListFluent.ItemsNested<A> setNewItemLike(int index,CSIStorageCapacity item);
  public CSIStorageCapacityListFluent.ItemsNested<A> editItem(int index);
  public CSIStorageCapacityListFluent.ItemsNested<A> editFirstItem();
  public CSIStorageCapacityListFluent.ItemsNested<A> editLastItem();
  public CSIStorageCapacityListFluent.ItemsNested<A> editMatchingItem(Predicate<CSIStorageCapacityBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,CSIStorageCapacityFluent<CSIStorageCapacityListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
